@@ -405,7 +405,7 @@ add_new_sources (ExchangeAccount *account)
 	GPtrArray *exchange_folders;
 
 	exchange_folders = exchange_account_get_folders (account);
-        if (exchange_folders && exchange_folders->len > 0) {
+	if (exchange_folders && exchange_folders->len > 0) {
 		gint i;
 		const gchar *folder_type;
 		const gchar *folder_name;
@@ -449,7 +449,7 @@ add_new_sources (ExchangeAccount *account)
 							folder_name, folder_uri);
 			} /* End hierarchy type check */
 		} /* End for loop */
-        } /* End check for a list of folders */
+	} /* End check for a list of folders */
 }
 
 static void
@@ -458,7 +458,7 @@ add_sources (ExchangeAccount *account)
 	GPtrArray *exchange_folders;
 
 	exchange_folders = exchange_account_get_folders (account);
-        if (exchange_folders && exchange_folders->len > 0) {
+	if (exchange_folders && exchange_folders->len > 0) {
 		gint i;
 		const gchar *folder_type;
 		EFolder *folder;
@@ -499,7 +499,7 @@ add_sources (ExchangeAccount *account)
 		add_account_esources (account, folders);
 		g_slist_foreach (folders, (GFunc) g_free, NULL);
 		g_slist_free (folders);
-        }
+	}
 }
 #endif
 
@@ -512,7 +512,6 @@ remove_account_esource (ExchangeAccount *account,
 	GSList *groups;
 	GSList *sources;
 	GSList *ids, *node_to_be_deleted;
-	gboolean found_group;
 	const gchar *source_uid;
 	GConfClient *client;
 	ESourceList *source_list = NULL;
@@ -532,14 +531,13 @@ remove_account_esource (ExchangeAccount *account,
 							CONF_KEY_TASKS);
 
 	groups = e_source_list_peek_groups (source_list);
-	found_group = FALSE;
 
-	for (; groups != NULL && !found_group; groups = g_slist_next (groups)) {
+	for (; groups != NULL; groups = g_slist_next (groups)) {
 		group = E_SOURCE_GROUP (groups->data);
 
 		if (strcmp (e_source_group_peek_name (group), account->account_name) == 0
-                    &&
-                    strcmp (e_source_group_peek_base_uri (group), EXCHANGE_URI_PREFIX) == 0) {
+		    &&
+		    strcmp (e_source_group_peek_base_uri (group), EXCHANGE_URI_PREFIX) == 0) {
 			sources = e_source_group_peek_sources (group);
 
 			for (; sources != NULL; sources = g_slist_next (sources)) {
@@ -593,7 +591,7 @@ remove_account_esource (ExchangeAccount *account,
 			}
 			e_source_list_remove_group (source_list, group);
 			e_source_list_sync (source_list, NULL);
-			found_group = TRUE;
+			break;
 		}
 	}
 	g_object_unref (source_list);
@@ -637,7 +635,7 @@ change_passwd_cb (GtkWidget *button, ExchangeAccount *account)
 {
 	gchar *current_passwd, *new_passwd;
 
-	gtk_widget_hide (gtk_widget_get_toplevel(button));
+	gtk_widget_hide (gtk_widget_get_toplevel (button));
 	current_passwd = exchange_account_get_password (account);
 	new_passwd = exchange_get_new_password (current_passwd, TRUE);
 	exchange_account_set_password (account, current_passwd, new_passwd);
@@ -1352,16 +1350,15 @@ exchange_add_autocompletion_folders (GConfClient *gc_client, ExchangeAccount *ac
 	ESourceList *sl=NULL;
 	ESource *source;
 	GSList *groups;
-	gboolean found_group=FALSE;
 
 	sl = e_source_list_new_for_gconf (gc_client, CONF_KEY_CONTACTS);
 	groups = e_source_list_peek_groups (sl);
 
-	for (; groups != NULL && !found_group; groups = g_slist_next (groups)) {
+	for (; groups != NULL; groups = g_slist_next (groups)) {
 		ESourceGroup *group = E_SOURCE_GROUP (groups->data);
 
 		if (strcmp (e_source_group_peek_name (group), account->account_name) == 0
-                    &&
+		    &&
 		    strcmp (e_source_group_peek_base_uri (group), EXCHANGE_URI_PREFIX) == 0) {
 			GSList *sources = e_source_group_peek_sources (group);
 
@@ -1378,7 +1375,7 @@ exchange_add_autocompletion_folders (GConfClient *gc_client, ExchangeAccount *ac
 					break;
 				}
 			}
-			found_group = TRUE;
+			break;
 		}
 	}
 
@@ -1452,7 +1449,6 @@ remove_selected_non_offline_esources (ExchangeAccount *account, const gchar *gco
 	GSList *groups;
 	GSList *sources;
 	GSList *ids, *node_to_be_deleted;
-	gboolean found_group;
 	const gchar *source_uid;
 	GConfClient *client;
 	ESourceList *source_list = NULL;
@@ -1472,14 +1468,13 @@ remove_selected_non_offline_esources (ExchangeAccount *account, const gchar *gco
 	source_list = e_source_list_new_for_gconf ( client, gconf_key);
 
 	groups = e_source_list_peek_groups (source_list);
-	found_group = FALSE;
 
-	for (; groups != NULL && !found_group; groups = g_slist_next (groups)) {
+	for (; groups != NULL; groups = g_slist_next (groups)) {
 		group = E_SOURCE_GROUP (groups->data);
 
 		if (strcmp (e_source_group_peek_name (group), account->account_name) == 0
-                    &&
-                    strcmp (e_source_group_peek_base_uri (group), EXCHANGE_URI_PREFIX) == 0) {
+		    &&
+		    strcmp (e_source_group_peek_base_uri (group), EXCHANGE_URI_PREFIX) == 0) {
 			sources = e_source_group_peek_sources (group);
 
 			for (; sources != NULL; sources = g_slist_next (sources)) {
@@ -1510,8 +1505,8 @@ remove_selected_non_offline_esources (ExchangeAccount *account, const gchar *gco
 					g_slist_free (ids);
 				}
 			}
-			found_group = TRUE;
 			e_source_list_sync (source_list, NULL);
+			break;
 		}
 	}
 
